package dbControl;

import org.apache.beehive.controls.api.bean.AnnotationConstraints;
import org.apache.beehive.controls.api.bean.AnnotationMemberTypes.*;
import org.apache.beehive.controls.api.bean.AnnotationMemberTypes;
import org.apache.beehive.controls.api.bean.ControlInterface;
import org.apache.beehive.controls.api.bean.ControlInterface;
import org.apache.beehive.controls.api.properties.PropertySet;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.sql.Connection;
import java.util.Calendar;

@ControlInterface
public interface DatabaseControl
{

    /**
     * This constant can be used as the value for the maxRows member of the SQL PropertySet.
     * It indicates that all rows should be returned (i.e. no limit)
     */
    public final int MAXROWS_ALL = -1;

    /**
     * This class acts as a default value for the iteratorElementType member of the
     * SQL PropertySet.  It signals that no type has been defined for the method
     * (common if the method return type isn't itself an iterator)
     */
    public interface UndefinedIteratorType {}


    @PropertySet
    @Inherited
    @AnnotationConstraints.AllowExternalOverride
    @Retention(RetentionPolicy.RUNTIME)
    @Target({ElementType.TYPE, ElementType.FIELD})
    public @interface ConnectionDataSource
    {
    	String jndiName();   // no default ... value is required
    }

    @PropertySet
    @Inherited
    @Retention(RetentionPolicy.RUNTIME)
    @AnnotationConstraints.AllowExternalOverride // not sure we want to do this
    @Target( { ElementType.METHOD } )
    public @interface SQL
    {
        String statement()              default "";
        int maxRows()                   default MAXROWS_ALL;
        @AnnotationMemberTypes.Optional
        Class iteratorElementType()     default UndefinedIteratorType.class;

    }

    public Calendar getDataSourceCalendar();

    public void setDataSourceCalendar(Calendar cal);

    public Connection getConnection();
}
