/*
 * Copyright 2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Header:$
 */
package org.apache.beehive.samples.petstore.model;

import java.math.*;
import java.util.*;

public class Order
    implements java.io.Serializable {

    private int _orderId;

    private Date _orderDate;
    private Date _time;

    private String _courier;
    private BigDecimal _totalPrice;

    private String _creditCard;
    private String _exprDate;
    private String _cardType;
    private String _locale;
    private String _status;

    private int _lineNum;
    private boolean _shippingAddressIsBillingAddress;

    private Account _account = null;
    private Cart _cart = null;

    private Address _shippingAddress = null;
    private Address _billingAddress = null;

    public Order(int orderId) {
        _orderId = orderId;
    }

    public void initOrder(Account account, Cart cart) {
        _account = account;
        _billingAddress = account.getAddress();
        _cart = cart;
        _orderDate = new Date();
        _totalPrice = _cart.getSubTotal();
    }

    public Account getAccount() {
        return _account;
    }

    public Cart getCart() {
        return _cart;
    }

    public int getOrderId() {
        return _orderId;
    }

    public void setOrderId(int orderId) {
        _orderId = orderId;
    }

    public Date getOrderDate() {
        return _orderDate;
    }

    public void setOrderDate(Date orderDate) {
        _orderDate = orderDate;
    }

    public Date getTime() {
        return _time;
    }

    public void setTime(Date time) {
        _time = time;
    }

    public String getCourier() {
        return _courier;
    }

    public void setCourier(String courier) {
        _courier = courier;
    }

    public BigDecimal getTotalPrice() {
        return _totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        _totalPrice = totalPrice;
    }

    public String getCreditCard() {
        return _creditCard;
    }

    public void setCreditCard(String creditCard) {
        _creditCard = creditCard;
    }

    public String getExprDate() {
        return _exprDate;
    }

    public void setExprDate(String exprDate) {
        _exprDate = exprDate;
    }

    public String getCardType() {
        return _cardType;
    }

    public void setCardType(String cardType) {
        _cardType = cardType;
    }

    public String getLocale() {
        return _locale;
    }

    public void setLocale(String locale) {
        _locale = locale;
    }

    public String getStatus() {
        return _status;
    }

    public void setStatus(String status) {
        _status = status;
    }

    public int getLineNum() {
        return _lineNum;
    }

    public void setLineNum(int lineNum) {
        _lineNum = lineNum;
    }

    public void setShippingAddressIsBillingAddress(boolean shippingAddressIsBillingAddress) {
        _shippingAddressIsBillingAddress = shippingAddressIsBillingAddress;
    }

    public boolean getShippingAddressIsBillingAddress() {
        return _shippingAddressIsBillingAddress;
    }

    public Address getShippingAddress() {
        if(_shippingAddress == null)
            _shippingAddress = createAddress();

        return _shippingAddress;
    }

    public void setShippingAddress(Address shippingAddress) {
        _shippingAddress = shippingAddress;
    }

    public Address getBillingAddress() {
        if(_billingAddress == null)
            _billingAddress = createAddress();

        return _billingAddress;
    }

    public void setBillingAddress(Address billingAddress) {
        _billingAddress = billingAddress;
    }

    private Address createAddress() {
        return new Address();
    }
}
