package org.apache.beehive.sample;

/*
 * Copyright 2004, 2005 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Header:$Factory
 */

import javax.xml.namespace.QName;

import javax.xml.rpc.handler.Handler;
import javax.xml.rpc.handler.HandlerInfo;
import javax.xml.rpc.handler.MessageContext;
import javax.xml.rpc.handler.soap.SOAPMessageContext;

import javax.xml.soap.SOAPMessage;

public class MessageHandler implements Handler {
    
    private static final String ORIGINAL = "original";
    private static final String MODIFIED = "ORIGINAL";

    private HandlerInfo info;
    private String modified;
    private String original;

    public void init(HandlerInfo handlerInfo) {

        info = handlerInfo;
        
        original = (String) info.getHandlerConfig().get("original");
        if (null == original || 0 == original.length()) {
            original = ORIGINAL;
        }
        
        modified = (String) info.getHandlerConfig().get("modified");
        if (null == modified || 0 == modified.length()) {
            modified = MODIFIED;
        }
    }

    public void destroy() {
        // empty
    }

    public QName[] getHeaders() {
        return info.getHeaders();
    }

    public boolean handleRequest(MessageContext mc) {
        boolean result = false;
        try {
            System.out.println("*** MessageHandler: handling message; initialized with <original>=" + original + ", <modified>=" + modified);
            SOAPMessage message = ((SOAPMessageContext) mc).getMessage();
            String value = message.getSOAPBody().getFirstChild().getFirstChild().getFirstChild().getNodeValue();
            if ((null != value) && value.equals(original)) {
                message.getSOAPBody().getFirstChild().getFirstChild().getFirstChild().setNodeValue(modified);
                System.out.println("*** Replacing: " + original + " with: " + modified);
            } 
            else {
                System.out.println("*** Not replacing: " + original);
            }
            result = true;
        }
        catch (Throwable t) {
            t.printStackTrace();
        }
        return result;
    }

    public boolean handleResponse(MessageContext mc) {
        return true;
    }

    public boolean handleFault(MessageContext mc) {
        return true;
    }
}
